pub fn run_with_strategy(
args: ResumeArgs,
exec: &dyn ExecStrategy,
) -> Result<()>Expand description
Internal entry point that the integration tests call with a
RecordingExec strategy. Production callers use run.
pub fn run_with_strategy(
args: ResumeArgs,
exec: &dyn ExecStrategy,
) -> Result<()>Internal entry point that the integration tests call with a
RecordingExec strategy. Production callers use run.